======================
Zertrin Python Toolbox
======================


.. image:: https://img.shields.io/pypi/v/zkpytb.svg
        :target: https://pypi.python.org/pypi/zkpytb
        :alt: PyPI Package latest release

.. image:: https://img.shields.io/travis/zertrin/zkpytb.svg
        :target: https://travis-ci.org/zertrin/zkpytb
        :alt: Travis-CI Build status

.. image:: https://coveralls.io/repos/github/zertrin/zkpytb/badge.svg?branch=master
        :target: https://coveralls.io/github/zertrin/zkpytb?branch=master
        :alt: Coverage status

.. image:: https://readthedocs.org/projects/zkpytb/badge/?version=latest
        :target: https://zkpytb.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/zkpytb.svg
        :target: https://pypi.python.org/pypi/zkpytb
        :alt: Supported Versions

.. image:: https://img.shields.io/github/license/zertrin/zkpytb.svg
        :target: https://github.com/zertrin/zkpytb
        :alt: License


A collection of useful functions by Zertrin


* Free software: MIT license
* Documentation: https://zkpytb.readthedocs.io.


Features
--------

.. list-table::
   :header-rows: 1

   * - Module
     - Description
   * - zkpytb.dicts
     - Helper functions for dictionaries.
   * - zkpytb.json
     - Helpers related to json.
   * - zkpytb.logging
     - Helper functions for logging.
   * - zkpytb.pandas
     - Helper functions for Pandas.
   * - zkpytb.priorityqueue
     - An implementation of PriorityQueue based on heapq.
   * - zkpytb.utils
     - Miscellaneous helper functions.

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

